#
# spec file for package python-ttp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -%{flavor}
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-ttp%{psuffix}
Version:        0.9.5
Release:        2.3
Summary:        Template Text Parser
License:        MIT
URL:            https://github.com/dmulyalin/ttp
Source:         https://github.com/dmulyalin/ttp/archive/refs/tags/%{version}.tar.gz#/ttp-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix-tests.patch gh#dmulyalin/ttp#90
Patch0:         fix-tests.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1.0.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module Cerberus}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module deepdiff}
BuildRequires:  %{python_module jinja2}
BuildRequires:  %{python_module openpyxl}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tabulate}
BuildRequires:  %{python_module ttp = %{version}}
BuildRequires:  %{python_module ttp-templates}
%endif
BuildRequires:  fdupes
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
TTP is a Python library for semi-structured text parsing using templates.

%prep
%autosetup -p1 -n ttp-%{version}
rm ttp/utils/load_python_exec_py2.py

%build
%if !%{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/ttp
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
pushd test/pytest
# No python-yangson
donttest="yangson"
%pytest . -k "not ($donttest)"
popd
%endif

%post
%python_install_alternative ttp

%postun
%python_uninstall_alternative ttp

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/ttp
%{python_sitelib}/ttp
%{python_sitelib}/ttp-%{version}*-info
%endif

%changelog
* Mon Apr  8 2024 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.5:
  * 1. group `to_int` function improved handling of missing keys,
  * 2. group `to_int` function added support to handle list of
    integers conversion, #109
  * 3. group `to_int` function improved best effort conversion
    logic to not fail on any conversion error at all
* Tue May  2 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to version 0.9.4:
  * Better fix for issue #103 and fix for issue #95
- 0.9.3:
  * Fix issue #103 - introduced login to not run validation check for
    group function for group tail match results
  * Fix for issue #97 - improoved path formatters handling when match
    variable contains *
  * Fix issue #98 - improoved pat formatters handling when match
    variable contains \
  * For debug output excluded 'ttp' dictionary from variables, groups
    and template objects to not clutter the output
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.9.2
  BUGS
  * Fix for issue #94
  FEATURES
  * Added match variable copy funtion
  * Added new ttp parser method get_templates to emit fully constructed templates after processing all extend tags
* Mon Oct 24 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add python-ttp-templates dependency to test build requirements
* Mon Oct 24 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python-ttp-templates dependency
* Fri Oct 21 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove %%files for test multibuild
* Fri Oct 21 2022 Daniel Garcia <daniel.garcia@suse.com>
- Initial packaging (v0.9.1) needed by python-napalm
